@@ -9,6 +9,10 @@ function(b,c,conf.level)
   u <- (B + sqrt(B^2-4*A*C))/(2*A)
   ll <- l/(1-l)
   ul <- u/(1-u)
-  c(ll,ul)
+  cint <- c(ll, ul)
+  attr(cint, "conf.level") <- conf.level
+  rval <- list(conf.int = cint)
+  class(rval) <- "htest"
+  return(rval)
 }
 
